@@ -22,10 +22,13 @@ import cangjie
 from tests import BaseTestCase, MetaTest
 
 
-class VersionThreeBig5HKSCSTestCase(BaseTestCase, unittest.TestCase,
-                                    metaclass=MetaTest):
-    # For now, this is the only scenario we can test, as we rely on the
-    # libcangjie_cli tool, and it only implements this
-    # FIXME: Improve libcangjie_cli so we can cover other cases
+class VersionThreeTestCase(BaseTestCase, metaclass=MetaTest):
+    cli_options = ["--filter=big5,hkscs,punctuation,chinese,zhuyin,kanji,katakana,hiragana,symbols",
+                   "--mode=code", "--cj-version=3"]
     version = cangjie.versions.CANGJIE3
-    language = cangjie.filters.BIG5 | cangjie.filters.HKSCS
+
+
+class VersionFiveTestCase(BaseTestCase, metaclass=MetaTest):
+    cli_options = ["--filter=big5,hkscs,punctuation,chinese,zhuyin,kanji,katakana,hiragana,symbols",
+                   "--mode=code", "--cj-version=5"]
+    version = cangjie.versions.CANGJIE5
